Extent

Struct Extent 

pub struct Extent { /* private fields */ }
Either a single Timestamp for a point in time, or a pair of Timestamps for a range.

Implementations

Source

impl Extent

pub fn point(ts: Timestamp) -> Self

Create an extent for a point in time.

pub fn range(ts: Range<Timestamp>) -> Self

Create an extent for a range.

The end of the range should be after the start, but an empty range is still considered a range.

pub fn as_point(&self) -> &Timestamp

Get the extent as a point in time.

For point extents, this will return exactly the value the extent was created from. For range extents, this will return the end bound.

pub fn as_range(&self) -> Option<&Range<Timestamp>>

Try get the extent as a range.

This method will return Some if the extent is a range, even if that range is empty. It will return None for point extents.

pub fn len(&self) -> Option<Duration>

Try get the length of the extent.

This method will return Some if the extent is a range, even if that range is empty. It will return None for point extents.

pub fn is_point(&self) -> bool

Whether the extent is a single point in time.

pub fn is_range(&self) -> bool

Whether the extent is a range.