Module str

Module str 

The Str type.

This module implements a string type that combines Cow<'static, str> with Cow<'a, str>. A Str can hold borrowed, static, owned, or shared data. Internally, it’s more efficient than a std::borrow::Cow to access because it doesn’t need to hop through enum variants.

Values can be converted into Strs either directly using methods like Str::new, or generically through the ToStr trait.

Strs are used in place of str or String as keys in crate::props::Props and fragments of crate::template::Templates.

Structs

Str
A string value.

Traits

ToStr
Convert a reference to a Str.