pub struct Render<'a, P> { /* private fields */ }Expand description
The result of calling Template::render.
The template can be converted to text either using the fmt::Display implementation of Render, or by calling Render::write with an instance of Write.
Implementations
Sourceimpl<'a, P> Render<'a, P>
impl<'a, P> Render<'a, P>
Sourcepub fn with_props<U>(self, props: U) -> Render<'a, U>
pub fn with_props<U>(self, props: U) -> Render<'a, U>
Set the properties to interpolate.
Sourcepub fn with_escaping(self, escape: bool) -> Self
pub fn with_escaping(self, escape: bool) -> Self
Whether to escape { and } in text fragments as {{ and }}.
Rendering will not escape by default.
Sourcepub fn as_literal(&self) -> Option<&Str<'a>>
pub fn as_literal(&self) -> Option<&Str<'a>>
Try get the value of the template as a string literal.