pub struct Extent { /* private fields */ }Expand description
Implementations
Sourceimpl Extent
impl Extent
Sourcepub fn range(ts: Range<Timestamp>) -> Self
pub fn range(ts: Range<Timestamp>) -> Self
Create an extent for a range.
The end of the range should be after the start, but an empty range is still considered a range.
Sourcepub fn as_point(&self) -> &Timestamp
pub fn as_point(&self) -> &Timestamp
Get the extent as a point in time.
For point extents, this will return exactly the value the extent was created from. For range extents, this will return the end bound.
Sourcepub fn as_range(&self) -> Option<&Range<Timestamp>>
pub fn as_range(&self) -> Option<&Range<Timestamp>>
Try get the extent as a range.
This method will return Some if the extent is a range, even if that range is empty. It will return None for point extents.